<?php
namespace Teknisa\PLA\Modules\Parametros\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\Report\ReportService;

class Pla03300Report extends \Zeedhi\Framework\Controller\Report {

    protected $reportService;
    protected $qr2Strategy;
    protected $util;
    protected $environment;
    protected $crudService;
    protected $nrlista;

    public function __construct($reportService, $qr2Strategy, $util, $environment, $crudService) {
    	$this->reportService = $reportService;
        $this->qr2Strategy = $qr2Strategy;
        $this->util = $util;
        $this->environment = $environment;
    	$this->crudService = $crudService;
    }

    protected $reportMapping = array (
    "PLA33000" =>
        array (
            "strategy" => "QR2",
            "parameterMapping" =>
            array (
                "NRLISTA"   => "NRLISTA",
                "DTVIGINI"  => "DTINICIAL",
                "DTVIGFIN"  => "DTFINAL",
                "NRORG"     => "NRORG",
                "IDTIPORESTRICAO" => "P_IDTIPORESTRICAO"
            )
        )
    );

    public function createRemoteReport(DTO\Request\Row $request, DTO\Response $response) {
        try {
            $this->beforeProcessReport($request, $response);
            $reportURL = $this->processReport($request);
            $response->addMessage(new DTO\Response\Message($reportURL));
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        } finally {
            $this->util->deleteLista($this->nrlista);
        }
    }

    public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response) {
    	$row = $request->getRow();
        $cdfiliserv = $this->getCdfiliserv($row);
        $this->nrlista = $this->util->insertLista($cdfiliserv);
        $row["NRLISTA"] = $this->nrlista;
        $row["NRORG"] = $this->environment->getNrOrg();
    	$this->qr2Strategy->setQr2Type($row['QR2TYPE']);
    }

    public function getCdfiliserv($row) {
        if ($row["NMSERVICO_ALL"] != "T") {
            return $row["CDFILISERV"];
        } else {
            $cdfilial = $row['NMFILIAL_ALL'] == "T" ? $row['NMFILIAL_ALL'] : implode("_",$row['CDFILIAL']);
            $conditions = array(
                array(
                    "columnName" => "CDFILIAL",
                    "operator"   => '=',
                    "value"      => $cdfilial
                ),
                array(
                    "columnName" => "CDGRUPSERV",
                    "operator"   => '=',
                    "value"      => "T"
                ),
                array(
                    "columnName" => "CDOPERADOR",
                    "operator"   => '=',
                    "value"      => "OPERADOR_LOGADO"
                )
            );
            $dataSet = $this->crudService->getFilteredDataSet("pla03300_servico_filial_filioper_operador", $conditions);
            $rows = $dataSet->getRows();
            $cdfiliserv = array();
            foreach ($rows as $row) {
                array_push($cdfiliserv, $row["CHAVE"]);
            }
            return $cdfiliserv;
        }
    }
} 
